@@ -1,7 +1,12 @@
 import copy, json
 import numpy as np
-import torch
-import torch.nn.functional as F
+try:
+    import torch
+    import torch.nn.functional as F
+except:
+    print('warning! pytorch not installed')
+    class torch():
+        Tensor = Exception
 from functools import wraps
 
 
